/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */



/////////////////////////////////////////////////////////////////////////////

// Version stamp for this .DLL

#include <windows.h>

#include <ver.h>



VS_VERSION_INFO     VERSIONINFO

  FILEVERSION       4 // major, minor, release (alpha 1), build #

  PRODUCTVERSION    4

  FILEFLAGSMASK     0

  FILEFLAGS         0 // final version

  FILEOS            VOS_DOS_WINDOWS16

  FILETYPE          VFT_DLL

  FILESUBTYPE       0   // not used

BEGIN

    BLOCK "StringFileInfo"

    BEGIN

        BLOCK "040904E4" // Lang=US English, CharSet=Windows Multilingual

        BEGIN

            VALUE "CompanyName",     "Netscape Communications Corporation\0"

            VALUE "FileDescription", "Netscape 16-bit JavaScript Debugger Module\0"

            VALUE "FileVersion",     "4.0\0"

            VALUE "InternalName",    "JSD1640\0"

            VALUE "LegalCopyright",  "Copyright Netscape Communications. 1994-96\0"

            VALUE "LegalTrademarks", "Netscape, Mozilla\0"

            VALUE "OriginalFilename","JSD1640.DLL\0"

            VALUE "ProductName",     "NETSCAPE\0"

            VALUE "ProductVersion",  "4.0\0"

        END

    END

END

